var app = getApp();
import * as echarts from '../../component/ec-canvas/echarts';

// 柱状图
let chartWeek = null;
function weekInitChart(canvas, width, height) {
  chartWeek = echarts.init(canvas, null, {
    width: width,
    height: height
  });
  canvas.setChart(chartWeek);

  var option = {
    color: ['#54585f'],
    tooltip: {
      show: false
    },
    grid: {
      left: 5,
      right: 5,
      bottom: 15,
      top: 30,
      height: 150,
      // show: true,
      containLabel: true,
      // borderColor: '#c9f1ce'
    },
    xAxis: [
      {
        type: 'category',
        data: ['周日\n5.11', '周一\n5.12', '周二\n5.13', '周三\n5.14', '周四\n5.15', '周五\n5.16', '周六\n5.17'],
        axisLine: {
          lineStyle: {
            color: '#c9f1ce'
          }
        },
        axisTick:{
          length:0
        },
        axisLabel: {
          color: '#4f5051',
          fontSize: 11,
          lineHeight: 15
        }
      }
    ],
    yAxis: [
      {
        type: 'value',
        interval: 10,//强制间隔
        axisTick: { show: false },
        axisLine: {
          show: false //是否显示轴线
        },
        splitLine:{
          lineStyle:{
            color: ['#c9f1ce'],
            width: 1
          }
        },
        axisLabel: {
          color: '#4f5051',
          fontSize: 11
        }
      }
    ],
    series: [
      {
        type: 'bar',
        // silent: true,//不响应和触发鼠标事件
        hoverAnimation: false,//是否开启 hover 在拐点标志上的提示动画效果。
        label: {
          normal: {
            show: true,
            position: 'top',
            // position: 'inside',
            // offset: [0,-6],
            color: '#60d4c6',
            // formatter: function (params) {
            //   if (params.value > 0) {
            //       return params.value;
            //   } else {
            //       return '';
            //   }
            // }
          }
        },
        itemStyle: {
          normal: {
            color: new echarts.graphic.LinearGradient(0, 1, 0, 0, [{
                offset: 0,
                color: "#60d4c6" // 0% 处的颜色
            },{
                offset: 1,
                color: "#6be89b" // 100% 处的颜色
            }], false),
            barBorderRadius: [3, 3, 0, 0] //（顺时针左上，右上，右下，左下）
          }
        },
        data: [30, 3, 35, 45, 17, 22, 0]
      }
    ]
  };

  chartWeek.setOption(option);
  return chartWeek;
}

// 饼状图
let chartPie = null;
function pieInitChart(canvas, width, height) {
  chartPie = echarts.init(canvas, null, {
    width: width,
    height: height
  });
  canvas.setChart(chartPie);

  var option = {
    tooltip: {
      show: false
    },
    color:['#6debc2','#5bc8ee','#5c7ce7'],
    legend: {
      left: 'center',
      top: 'center',
      orient: 'vertical',
      // top: 10,
      textStyle:{
        color: '#4f5051',
        fontSize: 11
      },
      icon: "circle",
      itemWidth: 8,
      itemHeight: 8,
      itemGap: 15,//图例间隔
      data: ['静态训练','动态训练','单词训练']
    },
    series: [
      {
        // silent: true,//不响应和触发鼠标事件
        hoverAnimation: false,//是否开启 hover 在拐点标志上的提示动画效果。
        type: 'pie',
        // radius : '80%',
        radius: ['52%', '100%'],
        // center: ['50%', '60%'],
        data:[
          {value:48, name:'静态训练'},
          {value:28, name:'动态训练'},
          {value:24, name:'单词训练'}
        ],
        label:{//饼图图形上的文本标签
          normal:{
            show: true,
            position: 'inner', //标签的位置
            textStyle : {
              fontWeight : 300 ,
              fontSize : 14//文字的字体大小
            },
            formatter: '{d}%'
          }
        }
      }
    ]
  };

  chartPie.setOption(option);
  return chartPie;
}

// 左眼视力图
let leftEyeChart = null;
function leftEyeInitChart(canvas, width, height) {
  leftEyeChart = echarts.init(canvas, null, {
    width: width,
    height: height
  });
  canvas.setChart(leftEyeChart);

  var option = {
    tooltip: {
      show: false
    },
    grid: {
      bottom: 25,
      top: 20,
      right: 10
    },
    xAxis: {
      type: 'category',
      boundaryGap: false,
      axisLine: {
        lineStyle: {
          color: '#c9f1ce'
        }
      },
      axisTick:{
        length: 0,
      },
      axisLabel:{
        color: '#333',
        fontSize: 11
      },
      boundaryGap: true,
      data: ["12.31", "1.1", "1.2", "1.3", "1.4", "1.5", "1.5"]
    },
    yAxis: {
      type: 'value',
      interval: 0.2,//强制间隔
      axisTick: { show: false },
      axisLine: {
        show: false //是否显示轴线
      },
      splitLine:{//网格横线
        lineStyle:{
          color: ['#c9f1ce'],
          width: 1
        }
      },
      axisLabel: {
        color: '#333',
        fontSize: 10,
        showMinLabel: false //显示最小值
      },
      min: function(value) {
        return value.min - 0.2;
      },
      max: function(value) {
        return value.max + 0.2;
      }
    },
    series: [
      {
        name: '训练后',
        // silent: true,//不响应和触发鼠标事件
        hoverAnimation: false,//是否开启 hover 在拐点标志上的提示动画效果。
        type:'line',
        color:['#33d1c4'],
        symbolSize: 13,
        lineStyle: {
          width: 4
        },
        itemStyle:{
          borderWidth: 2//拐点圆边框
        },
        data:[4.7, 4.7, 4.9, 4.9, 5.1, 5.1, 5.1]
      },
      {
        name: '未训练',
        symbol:'circle',//实心圆点
        // silent: true,//不响应和触发鼠标事件
        hoverAnimation: false,//是否开启 hover 在拐点标志上的提示动画效果。
        type:'line',
        color:['#f7b500'],
        symbolSize: 6,//拐点圆的大小
        lineStyle: {
          width: 2
        },
        itemStyle:{
          normal:{
            borderColor:'#f7b500',  //拐点边框颜色
          }
        },
        data:[4.7, 4.5, 4.5, 4.3, 4.3, 4.1, 4.1]
      }
    ]
  };

  leftEyeChart.setOption(option);
  return leftEyeChart;
}
// 右眼视力图
let rightEyeChart = null;
function rightEyeInitChart(canvas, width, height) {
  rightEyeChart = echarts.init(canvas, null, {
    width: width,
    height: height
  });
  canvas.setChart(rightEyeChart);

  var option = {
    tooltip: {
      show: false
    },
    grid: {
      bottom: 25,
      top: 20,
      right: 10
    },
    xAxis: {
      type: 'category',
      boundaryGap: false,
      axisLine: {
        lineStyle: {
          color: '#c9f1ce'
        }
      },
      axisTick:{
        length:0,
      },
      axisLabel:{
        color: '#333',
        fontSize: 11
      },
      boundaryGap: true,
      data: ["12.31", "1.1", "1.2", "1.3", "1.4", "1.5", "1.5"]
    },
    yAxis: {
      type: 'value',
      interval: 0.2,//强制间隔
      axisTick: { show: false },
      axisLine: {
        show: false //是否显示轴线
      },
      splitLine:{//网格横线
        lineStyle:{
          color: ['#c9f1ce'],
          width: 1
        }
      },
      axisLabel: {
        color: '#333',
        fontSize: 10,
        showMinLabel: false //显示最小值
      },
      min: function(value) {
        return value.min - 0.2;
      },
      max: function(value) {
        return value.max + 0.2;
      }
    },
    series: [
      {
        name: '训练后',
        // silent: true,//不响应和触发鼠标事件
        hoverAnimation: false,//是否开启 hover 在拐点标志上的提示动画效果。
        type:'line',
        color:['#33d1c4'],
        symbolSize: 13,
        lineStyle: {
          width: 4
        },
        itemStyle:{
          borderWidth: 2
        },
        data:[4.7, 4.7, 4.9, 4.9, 5.1, 5.1, 5.1]
      },
      {
        name: '未训练',
        symbol:'circle',//实心圆点
        // silent: true,//不响应和触发鼠标事件
        hoverAnimation: false,//是否开启 hover 在拐点标志上的提示动画效果。
        type:'line',
        color:['#f7b500'],
        symbolSize: 6,//拐点圆的大小
        lineStyle: {
          width: 2
        },
        itemStyle:{
          normal:{
            borderColor:'#f7b500',  //拐点边框颜色
          }
        },
        data:[4.7, 4.5, 4.5, 4.3, 4.3, 4.1, 4.1]
      }
    ]
  };

  rightEyeChart.setOption(option);
  return rightEyeChart;
}

Page({
  data: {
    teenageName: '',
    gender: '',
    age: '',
    className: '',
    avatar: '',
    imgUrls: [
      '../../assets/h1.jpg',
      '../../assets/h2.jpg'
    ],
    indicatorDots: true,
    autoplay: false,
    interval: 5000,
    circular: true,
    weekChart: {
      onInit: weekInitChart
    },
    pieChart: {
      onInit: pieInitChart
    },
    leftEyeChart: {
      onInit: leftEyeInitChart
    },
    rightEyeChart: {
      onInit: rightEyeInitChart
    },
    leftYear: '2018',
    rightYear: '2019',
    trainSortList:[
      { id: 14, name: "豆包", self: false, time: '283分钟' },
      { id: 15, name: "雪诺", self: false, time: '280分钟' },
      { id: 16, name: "我", self: true, time: '158分钟' },
      { id: 17, name: "甜甜", self: false, time: '188分钟' }
    ],
    resultSortList:[
      { id: 1, name: "豆包", self: false, type: 'up',eye:'左', num: '0.5' },
      { id: 2, name: "雪诺", self: false, type: 'down',eye:'右', num: '0.4' },
      { id: 3, name: "甜甜", self: false, type: 'none',eye:'双', num: '0.3' },
      { id: 15, name: "我", self: true, type: 'up',eye:'双', num: '0.2' },
      { id: 4, name: "11甜", self: false, type: 'down',eye:'左', num: '0.3' },
      { id: 5, name: "3333", self: false, type: 'up',eye:'右', num: '0.3' }
    ],
    timerId: '',// 定时器id
    iswifi: true,
    checkImg: '../../assets/h2.jpg',

    mustUpdate: true,
    status: 1,
    
  },
  onShow() {
    let me = this;
    console.log('从子页面返回首页')

    // this.setData({
    //   status: 1,
    //   mustUpdate: false
    // })
    // 请求前加Loading
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wx.request({
      url: app.globalData.apiUrl + 'Users/index',
      method: 'POST',
      data: {
        token: wx.getStorageSync('token')
      },
      success: function (res) {
        // 请求成功后关闭Loading
        wx.hideLoading();
        if(res.data.errno==200){
          me.setData({
            teenageName: res.data.data.teenageName,
            gender: res.data.data.gender,
            age: res.data.data.age,
            avatar: res.data.data.avatar,
          })
          if(res.data.data.schoolName||res.data.data.classesName){
            me.setData({
              className: res.data.data.schoolName+res.data.data.classesName
            })
          }else{
            me.setData({
              className: '无'
            })
          }
        }else{
          wx.showModal({
            title: '提示',
            showCancel: false,
            content: res.data.msg
          })
        }
      }
    })

    // 获取网络类型
    wx.getNetworkType({
      success (res) {
        console.log(res.networkType)
        // wifi	: wifi 网络显示提示
        if(res.networkType == 'wifi'){
          me.setData({
            iswifi: true
          })
          // WiFi环境 5秒刷新一次
          me.timeImg(5000);
        }else{
          me.setData({
            iswifi: false
          })
          // 非WiFi环境 10秒刷新一次
          me.timeImg(10000);
        }
      }
    })
  },
  onReady() {
    // setTimeout(function () {
    //   // 获取 chartWeek 实例的方式
    //   console.log(chartWeek)
    // }, 2000);
  },
  onHide() {
    // 切换页面时，关闭定时器
    console.log(this.data.timerId);
    clearInterval(this.data.timerId);
  },
  // 权限设置
  ruleSet:function(){
    wx.navigateTo({
      url: '/pages/setting/setting'
    })
  },
  // 设置
  set:function(){
    wx.navigateTo({
      url: '/pages/ruleSet/ruleSet'
    })
  },
  // 训练计划
  plan:function(){
    wx.navigateTo({
      url: '/pages/plan/plan'
    })
  },
  // 小目标
  target:function(){
    wx.navigateTo({
      url: '/pages/targetList/targetList'
    })
  },
  // 立即关机
  PowerOff: function () {
    // 请求前加Loading
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wx.request({
      url: app.globalData.apiUrl + 'devices/close',
      method: 'POST',
      data: {
        token: wx.getStorageSync('token')
      },
      success: function (res) {
        // 请求成功后关闭Loading
        wx.hideLoading();
        if(res.data.errno==200){
          wx.showToast({
            title: '关机成功！',
            mask: true,
            // icon: 'none',
            duration: 2000
          });
        }else{
          wx.showModal({
            title: '提示',
            showCancel: false,
            content: res.data.msg
          })
        }
      }
    })
  },
  // 定时获取设备屏幕图片
  timeImg: function (delay) {
    let me = this;
    clearInterval(timer);
    var timer = setInterval(function () {
      // 暂时不加loading 影响操作（用户体验）
      // // 请求前加Loading
      // wx.showLoading({
      //   title: '加载中',
      //   mask: true
      // })

      //获取当前时间戳
      var timestamp = Date.parse(new Date());
      timestamp = timestamp / 1000;
      console.log("当前时间戳为：" + timestamp);
      wx.request({
        url: app.globalData.apiUrl + 'devices/watchingPic',
        method: 'POST',
        data: {
          token: wx.getStorageSync('token'),
          nowTime: timestamp // 当前时间戳，服务端会获取大于当前时间戳的图片信息
        },
        success: function (res) {
          // // 请求成功后关闭Loading
          // wx.hideLoading();
          if(res.data.errno==200){
            console.log(res.data.data.trainingStatus)//训练状态，1正在训练、0：未训练
            console.log(res.data.data.thumb)
            me.setData({
              checkImg: res.data.data.thumb
            })
            // wx.showToast({
            //   title: '关机成功！',
            //   mask: true,
            //   // icon: 'none',
            //   duration: 2000
            // });
          }else{
            clearInterval(timer);
            wx.showModal({
              title: '提示',
              showCancel: false,
              content: res.data.msg
            })
          }
        }
      })
    }, delay);
    me.setData({
      timerId: timer
    })
  },
  preventTouchMove() {},
  // 个人中心
  toMine() {
    wx.navigateTo({
      url: '/pages/mine/mine'
    })
  },
  // 稍后前往
  lastGo: function () {
    // 关闭当前页面
    this.setData({
      mustUpdate: true
    })
  },
  // 一键前往
  nowGo: function () {
    // 关闭当前页面，跳转到 "训练计划"
    wx.navigateTo({
      url: '/pages/plan/plan'
    })
  },
})